@@ -4,12 +4,12 @@
 		<message>
 			<location filename="com.deepin.diskmanager!message" line="0"/>
 			<source>Authentication is required to read disk information</source>
-			<translation>Uwierzytelnienie jest wymagane aby odczytywać informacje z dysku</translation>
+			<translation>Wymagane jest uwierzytelnienie, aby odczytywać informacje o dyskach</translation>
 		</message>
 		<message>
 			<location filename="com.deepin.diskmanager!description" line="0"/>
 			<source>Run Disk Manager Need Authentication</source>
-			<translation>Uruchomienie menadżera dysku wymaga uwierzytelnienia</translation>
+			<translation>Run Disk Manager Need Authentication</translation>
 		</message>
 	</context>
 </TS>
\ No newline at end of file
