@@ -136,8 +136,12 @@ void PartChartShowing::addPaint(QPainter *painter)
     rect.setY(y());
     rect.setWidth(width());
     QRect paintRect = QRect(3, 10, rect.width() - 4, 35);
-    QPainterPath path0, path1, path2, path3, path4, path5, path6, path7, path8, path9, path10, path11, path12, path13, path14, path15, path16, path17, path18, path19, path20, path21, path22, path23;
-    QVector<QPainterPath> path {path0, path1, path2, path3, path4, path5, path6, path7, path8, path9, path10, path11, path12, path13, path14, path15, path16, path17, path18, path19, path20, path21, path22, path23};
+    QVector<QPainterPath> path;
+    for (int i = 0; i < m_partSize.size(); i++) {
+        QPainterPath painterPath;
+        path.append(painterPath);
+    }
+
     QPainterPath paintPath;
     double sum = 0.00;
     //绘制默认选中状态
