@@ -57,7 +57,7 @@ void SizeInfoWidget::setData(PartitionInfo info, QVector<QColor> color, QVector<
 
     m_noused = Utils::sectorToUnit(info.m_sectorsUnused, info.m_sectorSize, SIZE_UNIT::UNIT_GIB);
     m_used = Utils::sectorToUnit(info.m_sectorsUsed, info.m_sectorSize, SIZE_UNIT::UNIT_GIB);
-    m_totalSpaceSize = Utils::formatSize(info.m_sectorEnd - info.m_sectorStart, info.m_sectorSize);
+    m_totalSpaceSize = Utils::formatSize(info.m_sectorEnd - info.m_sectorStart + 1, info.m_sectorSize);
     m_usedSize = Utils::formatSize(info.m_sectorsUsed, info.m_sectorSize);
     m_totalSize = m_noused + m_used;
     m_partitionPath = info.m_path;
@@ -70,6 +70,35 @@ void SizeInfoWidget::setData(PartitionInfo info, QVector<QColor> color, QVector<
     update();
 }
 
+void SizeInfoWidget::setData(LVInfo info, QVector<QColor> color, QVector<double> size, bool flag)
+{
+    m_sizeInfo = size;
+    m_colorInfo = color;
+    m_flag = flag;
+    m_partitionPath = info.m_lvName;
+    m_totalSpaceSize = info.m_lvSize;
+    if (m_totalSpaceSize.contains("1024")) {
+        m_totalSpaceSize = Utils::LVMFormatSize(info.m_lvLECount * info.m_LESize + info.m_LESize);
+    }
+
+    m_used = Utils::LVMSizeToUnit(info.m_fsUsed, SIZE_UNIT::UNIT_GIB);
+    m_noused = Utils::LVMSizeToUnit(info.m_fsUnused, SIZE_UNIT::UNIT_GIB);
+    if (info.m_lvName.isEmpty() && info.m_lvUuid.isEmpty()) {
+        m_noused = Utils::LVMSizeToUnit(info.m_lvLECount * info.m_LESize, SIZE_UNIT::UNIT_GIB);
+    }
+
+    m_totalSize = m_noused + m_used;
+    if (m_totalSize <= 0) {
+        m_totalSize = Utils::LVMSizeToUnit(info.m_lvLECount * info.m_LESize, SIZE_UNIT::UNIT_GIB);
+    }
+    m_usedSize = Utils::LVMFormatSize(info.m_fsUsed);
+
+    if (size.at(0) < 0.00 || size.at(1) < 0.00) {
+        m_sizeInfo = QVector<double> {0.00, 0.00};
+    }
+    update();
+}
+
 void SizeInfoWidget::paintEvent(QPaintEvent *event)
 {
     QWidget::paintEvent(event);
