@@ -30,6 +30,7 @@
 #include "customcontrol/ddbase.h"
 
 #include <QWidget>
+#include <DLabel>
 
 DWIDGET_USE_NAMESPACE
 
@@ -44,6 +45,13 @@ class PartitionDialog : public DDBase
 public:
     explicit PartitionDialog(QWidget *parent = nullptr);
 
+    /**
+     * @brief 设置标题内容
+     * @param title 标题内容
+     * @param subTitle 副标题内容
+     */
+    void setTitleText(const QString &title, const QString &subTitle = "");
+
 private:
     /**
      * @brief 初始化界面
@@ -54,6 +62,8 @@ signals:
     //    void showPartWidget();
 public slots:
     //    void sendSignal(int index);
+private:
+    DLabel *m_tipLabel;
 };
 
 #endif // PARTITIONDIALOG_H
