@@ -25,6 +25,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "lvmstruct.h"
 #include "utils.h"
 
 #include <sys/statvfs.h>
@@ -33,6 +34,8 @@
 #include <QRegularExpression>
 #include <QUuid>
 #include <QDebug>
+#include <algorithm>
+#include <math.h>
 
 Utils::Utils()
 {
@@ -52,7 +55,8 @@ QString Utils::findProgramInPath(const QString &proName)
 
 int Utils::executeCmdWithArtList(const QString &strCmd, const QStringList &strArg, QString &outPut, QString &error)
 {
-    //qDebug() << "Utils::executeCmdWithArtList----+=" << strcmd;
+    qDebug() << "Utils::executeCmdWithArtList cmd:  " << strCmd;
+    qDebug() << "Utils::executeCmdWithArtList argList:  " << strArg;
     QProcess proc;
     // proc.open(QIODevice::ReadWrite);
     //proc.start(strcmd, strarg);
@@ -64,7 +68,7 @@ int Utils::executeCmdWithArtList(const QString &strCmd, const QStringList &strAr
     outPut = proc.readAllStandardOutput().data();
     error = proc.errorString();
     int exitcode = proc.exitCode();
-    //qDebug() << "Utils::executeCmdWithArtList----" << output << error;
+
     proc.close();
     return exitcode;
 }
@@ -89,16 +93,46 @@ int Utils::executCmd(const QString &strCmd, QString &outPut, QString &error)
 //    }
 //    proc.close();
 
-    QStringList cmdList = strCmd.split(" ");
+    QStringList cmdList = strCmd.trimmed().split(" ");
+
     QStringList argList;
     for (int i = 1; i < cmdList.size(); i++) {
-        argList.append(cmdList[i]);
+        if (!cmdList[i].isEmpty()) {
+            argList.append(cmdList[i]);
+        }
     }
-    int exitcode = executeCmdWithArtList(cmdList[0],argList, outPut, error);
+    int exitcode = executeCmdWithArtList(cmdList[0], argList, outPut, error);
 
     return exitcode;
 }
 
+int Utils::executWithPipeCmd(const QString &strCmd, QString &outPut, QString &error)
+{
+    QStringList argList;
+    argList << "-c" << strCmd;
+
+    return executeCmdWithArtList("/bin/bash", argList, outPut, error);
+}
+
+int Utils::executWithErrorCmd(const QString &strCmd, const QStringList &strArg, QString &outPut, QString &outPutError, QString &error)
+{
+    qDebug() << "Utils::executWithErrorCmd cmd:  " << strCmd;
+    qDebug() << "Utils::executWithErrorCmd argList:  " << strArg;
+    QProcess proc;
+
+    proc.setProgram(strCmd);
+    proc.setArguments(strArg);
+    proc.start(QIODevice::ReadWrite);
+
+    proc.waitForFinished(-1);
+    outPut = proc.readAllStandardOutput().data();
+    outPutError = proc.readAllStandardError();
+    error = proc.errorString();
+    int exitcode = proc.exitCode();
+    proc.close();
+    return exitcode;
+}
+
 QString Utils::regexpLabel(const QString &strText, const QString &strPatter)
 {
     QString strSource = strText;
@@ -505,3 +539,106 @@ QString Utils::createUuid()
     QUuid uuid;
     return uuid.createUuid().toString(QUuid::WithoutBraces);
 }
+
+
+QString Utils::LVMFormatSize(long long lvmSize)
+{
+    QString res;
+    if (lvmSize  < KIBIBYTE) {
+        res = res.setNum(LVMSizeToUnit(lvmSize, UNIT_BYTE), 'f', 2);
+        res.append(" B");
+    } else if (lvmSize < MEBIBYTE) {
+        res = res.setNum(LVMSizeToUnit(lvmSize, UNIT_KIB), 'f', 2);
+        res.append(" KiB");
+    } else if (lvmSize < GIBIBYTE) {
+        res = res.setNum(LVMSizeToUnit(lvmSize, UNIT_MIB), 'f', 2);
+        res.append(" MiB");
+    } else if (lvmSize < TEBIBYTE) {
+        res = res.setNum(LVMSizeToUnit(lvmSize, UNIT_GIB), 'f', 2);
+        res.append(" GiB");
+    } else {
+        res = res.setNum(LVMSizeToUnit(lvmSize, UNIT_TIB), 'f', 2);
+        res.append(" TiB");
+    }
+    return res;
+}
+
+double Utils::LVMSizeToUnit(long long lvmSize, SIZE_UNIT sizeUnit)
+{
+    double res = 0.0;
+    switch (sizeUnit) {
+    case UNIT_BYTE:
+        res = lvmSize ;
+        break;
+    case UNIT_KIB:
+        res = lvmSize / static_cast<double>(KIBIBYTE) ;
+        break;
+    case UNIT_MIB:
+        res = lvmSize / static_cast<double>(MEBIBYTE);
+        break;
+    case UNIT_GIB:
+        res = lvmSize / static_cast<double>(GIBIBYTE);
+        break;
+    case UNIT_TIB:
+        res = lvmSize / static_cast<double>(TEBIBYTE);
+        break;
+    default:
+        res = lvmSize;
+    }
+    return res;
+}
+
+bool Utils::adjudicationPVDelete(LVMInfo lvmInfo, const set<QString> &pvStrList, bool &bigDataMove, QStringList &realMovePvList)
+{
+    bigDataMove = false;
+    //获取所有存在于vg中 待删除的pv
+    QMap<QString, QVector<QString>>t_map;
+    foreach (auto pvPath, pvStrList) {
+        if (!lvmInfo.pvExists(pvPath)) { //pv不存在
+            return false;
+        }
+
+        PVInfo pv =  lvmInfo.getPV(pvPath);
+        if(pv.noJoinVG()){              //只获取加入vg的pv路径
+            continue;
+        }
+
+        if (!lvmInfo.pvOfVg(pv)) {      //vg不存在或pv不在vg中 说明数据有错误
+            return false;
+        }
+        t_map[pv.m_vgName].push_back(pv.m_pvPath);
+    }
+
+    //判断pv是否可以删除
+    long long remvoeAllSize = 0;
+    for (QMap<QString, QVector<QString>>::iterator it = t_map.begin(); it != t_map.end(); ++it) {
+        long long remvoePE = 0;
+        long long unusedPE = 0;
+        VGInfo vgInfo = lvmInfo.getVG(it.key());
+        foreach (const QString &path, it.value()) { //需要删除的pv
+            auto pvIt = vgInfo.m_pvInfo.find(path);
+            if (pvIt != vgInfo.m_pvInfo.end()) {
+                if (pvIt->m_pvUsedPE > 0) {
+                    realMovePvList.push_back(pvIt->m_pvPath);
+                    remvoePE += pvIt->m_pvUsedPE;
+                }
+                unusedPE += pvIt->m_pvUnusedPE;
+            }
+        }
+        if (vgInfo.m_peUnused - unusedPE < remvoePE) { //判断是否允许删除
+            return false;
+        }
+
+        if (!bigDataMove) { //判断是否存在大量数据需要移动
+            remvoeAllSize += (remvoePE * vgInfo.m_PESize);
+            bigDataMove = ((remvoeAllSize / GIBIBYTE) >= 1);
+        }
+    }
+    return true;
+}
+
+
+
+
+
+
