@@ -33,6 +33,7 @@
 #include "supportedfilesystems.h"
 #include "thread.h"
 #include "DeviceStorage.h"
+#include "lvmoperator/lvmoperator.h"
 
 #include <QObject>
 #include <QVector>
@@ -67,6 +68,13 @@ public:
      */
     DeviceInfoMap getAllDeviceinfo();
 
+
+    /**
+     * @brief 获取LVM设备信息
+     * @return 返回LVM设备信息
+     */
+    LVMInfo getAllLVMinfo();
+
     /**
      * @brief 获取当前页面选择分区信息
      * @param info：当前选择分区信息
@@ -81,12 +89,6 @@ public:
      */
     bool mountAndWriteFstab(const QString &mountpath);
 
-    /**
-     * @brief 临时挂载分区
-     * @param mountpath：挂载路径
-     * @return true成功false失败
-     */
-    bool mountTemp(const QString &mountpath);
 
     /**
      * @brief 卸载分区
@@ -114,11 +116,11 @@ public:
      * @param fstype：格式化格式
      * @param path：分区别名
      * @param name: 劵标名
-     * @param diskType : 0为分区，1为磁盘，2为空闲
-     * @param clearType: 清除标准， 0为快速，1为安全（NIST），2为DoD标准， 3为古德曼标准
+     * @param diskType : 0为磁盘，1为分区
+     * @param clearType: 清除标准， 1为快速，2为安全（NIST），3为DoD标准， 4为古德曼标准
      * @return true成功false失败
      */
-    bool clear(const QString &fstype, const QString &path,const QString &name,const QString &user ,const int &diskType , const int &clearType);
+    bool clear(const QString &fstype, const QString &path, const QString &name, const QString &user, const int &diskType, const int &clearType);
 
     /**
      * @brief 扩容分区
@@ -220,7 +222,7 @@ public:
      * @param checkSize：检测柱面大小
      * @return true错误false正常
      */
-    bool checkBadBlocks(const QString &devicePath, int blockStart, int blockEnd, int checkConut, int checkSize,int flag);
+    bool checkBadBlocks(const QString &devicePath, int blockStart, int blockEnd, int checkConut, int checkSize, int flag);
 
     /**
      * @brief 坏道检测（超时时间）
@@ -271,6 +273,89 @@ public:
      */
     bool delTempMountFile();
 
+    /**
+    * @brief 判断设备有否经历过gpt分区表扩容
+    * @param devicePath：设备路径
+    * @return true扩展后gpt分区表状态与实际不一致, false分区表状态正常
+    */
+    bool gptIsExpanded(const QString &devicePath);
+
+    /**
+     * @brief 创建vg
+     * @param vgName:待创建vg名称
+     * @param devList: pv设备集合
+     * @param size:vg总大小
+     * @return true 成功 false 失败
+     */
+    bool createVG(QString vgName, QList<PVData>devList, long long size);
+
+    /**
+     * @brief 创建lv
+     * @param vgName:vg名称
+     * @param lvList: 待创建lv列表
+     * @return true 成功 false 失败
+     */
+    bool createLV(QString vgName, QList<LVAction>lvList);
+
+    /**
+     * @brief 删除vg
+     * @param vglist: 待删除vg列表
+     * @return true 成功 false 失败
+     */
+    bool deleteVG(QStringList vglist);
+
+    /**
+     * @brief 删除lv
+     * @param lvlist: 待删除lv列表
+     * @return true 成功 false 失败
+     */
+    bool deleteLV(QStringList lvlist);
+
+    /**
+     * @brief vg空间调整
+     * @param vgName:vg名称
+     * @param devList: pv设备集合
+     * @param size:调整后vg总大小
+     * @return true 成功 false 失败
+     */
+    bool resizeVG(QString vgName, QList<PVData>devList, long long size);
+
+    /**
+     * @brief lv空间调整
+     * @param lvAction:lv操作结构体
+     * @return true 成功 false 失败
+     */
+    bool resizeLV(LVAction &lvAction);
+
+    /**
+     * @brief lv挂载
+     * @param lvAction:lv操作结构体
+     * @return true 成功 false 失败
+     */
+    bool mountLV(const LVAction &lvAction);
+
+    /**
+     * @brief lv卸载
+     * @param lvAction:lv操作结构体
+     * @return true 成功 false 失败
+     */
+    bool umountLV(const LVAction &lvAction);
+
+    /**
+     * @brief lv清除
+     * @param lvAction:lv操作结构体
+     * @return true 成功 false 失败
+     */
+    bool clearLV(const LVAction &lvAction);
+
+
+    /**
+     * @brief pv删除
+     * @param devList: 待删除pv设备集合
+     * @return true 成功 false 失败
+     */
+    bool deletePVList(QList<PVData>devList);
+
 private:
 
     /**
@@ -321,11 +406,11 @@ private:
      * @param insideExtended：扩展分区标志
      */
     static void insertUnallocated(const QString &devicePath,
-                                   QVector<Partition *> &partitions,
-                                   Sector start,
-                                   Sector end,
-                                   Byte_Value sectorSize,
-                                   bool insideExtended);
+                                  QVector<Partition *> &partitions,
+                                  Sector start,
+                                  Sector end,
+                                  Byte_Value sectorSize,
+                                  bool insideExtended);
 
     /**
      * @brief 设置分区标志
@@ -352,7 +437,58 @@ private:
      * @param count: 循环次数
      * @return : 执行结果
      */
-    bool secuClear(const QString &path, const Sector &start, const Sector &end, const Byte_Value &size, const QString &fstype,const QString &name=" ", const int &count=1);
+    bool secuClear(const QString &path, const Sector &start, const Sector &end, const Byte_Value &size, const QString &fstype, const QString &name = " ", const int &count = 1);
+
+
+    /**
+     * @brief 挂载设备
+     * @param mountpath:挂载点
+     * @param devPath:设备路径
+     * @param fsType:文件系统类型
+     * @return true 挂载成功 false 挂载失败
+     */
+    bool mountDevice(const QString &mountpath, const QString devPath, const FSType &fsType);
+
+
+    /**
+     * @brief 卸载设备
+     * @param mountPoints:挂载点集合
+     * @return true 卸载成功 false 卸载失败
+     */
+    bool umontDevice(QVector<QString>mountPoints,QString devPath = "");
+
+    /**
+     * @brief 写fstab文件
+     * @param uuid:设备（磁盘分区，lvm lv）uuid
+     * @param mountpath:挂载点
+     * @param type:文件系统类型
+     * @param isMount:true 挂载 false 卸载
+     * @return true 写入成功 false 写入失败
+     */
+    bool writeFstab(const QString &uuid, const QString &mountpath, const QString &type, bool isMount = true);
+
+    /**
+     * @brief 创建临时挂载目录
+     * @param mountpath:挂载目录
+     * @return true 创建成功 false 创建失败
+     */
+    bool createTmpMountDir(const QString &mountPath);
+
+    /**
+     * @brief 修改文件属主
+     * @param user:用户名
+     * @param path:文件路径
+     * @return true 修改成功 false 修改失败
+     */
+    bool changeOwner(const QString &user, const QString &path);
+
+
+    /**
+     * @brief 创建pv使用的分区
+     * @param pv:pv数据结构体 创建分区依据
+     * @return true 分区创建成功 false 失败
+     */
+    bool createPVPart(PVData &pv);
 
 private:
     //general..
@@ -440,7 +576,7 @@ private:
      * @return true成功false失败
      */
     static bool getDeviceAndDisk(const QString &devicePath, PedDevice *&lpDevice,
-                                    PedDisk *&lpDisk, bool strict = true, bool flush = false);
+                                 PedDisk *&lpDisk, bool strict = true, bool flush = false);
 
     /**
      * @brief 更新到磁盘信息
@@ -689,6 +825,84 @@ private:
      */
     void reWritePartition(const QString &devicePath);
 
+    /**
+     * @brief 发送刷新信号并且返回bool值
+     * @param flag：设置的返回值
+     * @return true false 与flag相同
+     */
+    inline bool sendRefSigAndReturn(bool flag, int type = 0, bool arg1 = true, QString arg2 = "")
+    {
+        emit refreshDeviceInfo(type, arg1, arg2);
+        return flag;
+    }
+
+    /**
+     * @brief 获取创建VG的pvdata 列表
+     * @param devList: 设备列表
+     * @param size: 总大小
+     * @return true false 与flag相同
+     */
+    QList<PVData> getCreatePVList(const QList<PVData> &devList, const long long &totalSize);
+
+    /**
+     * @brief 获取vg调整后的pvdata 列表
+     * @param vgName:需要调整的vg
+     * @param devList: 设备列表
+     * @param size: 总大小
+     * @return true false 与flag相同
+     */
+    QList<PVData> getResizePVList(const QString &vgName, const QList<PVData> &devList, const long long &totalSize);
+
+    /**
+     * @brief 获取创建PV的磁盘
+     * @param devPath: 磁盘路径
+     * @param dev: 磁盘设备 传入参数
+     * @return true 获取成功 false 获取失败
+     */
+    bool getPVDevice(const QString &devPath, Device &dev);
+
+    /**
+     * @brief 获取创建PV的磁盘
+     * @param pv: pv数据结构体
+     * @param flag: pv需要创建分区表 标志位
+     * @return 大于0为pv长度 单位byte  小于0 为错误
+     */
+    long long getPVSize(const PVData &pv, bool flag = false);
+
+    /**
+     * @brief 获取创建PV的分区结尾
+     * @param pv: pv数据结构体
+     * @param unallocaSize: 未分配空间
+     * @return true 获取成功 false 获取失败
+     */
+    bool getPVStartEndSector(PVData &pv, const long long &unallocaSize);
+
+    /**
+     * @brief 创建pv分区
+     * @param pv: pv数据结构体
+     * @return true 获取成功 false 获取失败
+     */
+    bool createPVPartition(PVData &pv);
+
+    /**
+     * @brief 检查pv设备
+     * @param vgName: vg名称
+     * @param pv: pv数据结构体
+     * @return true 成功 允许使用 false 失败 不允许使用
+     */
+    bool checkPVDevice(const QString vgName, const PVData &pv, bool isCreate = true);
+
+    /**
+     * @brief 删除pv结束信号
+     * @param flag:true成功false失败
+     */
+    void deletePVListMessage(bool flag);
+
+    /**
+     * @brief vg调整结束信号
+     * @param flag:true成功false失败
+     */
+    void resizeVGMessage(bool flag);
 
 signals:
     void probeAllInfo();
@@ -703,10 +917,13 @@ signals:
      * @brief 更新信息信号
      * @param infomap：硬盘信息
      */
-    void updateDeviceInfo(const DeviceInfoMap &infomap);
+    void updateDeviceInfo(const DeviceInfoMap &infomap, const LVMInfo &lvmInfo);
 
     /**
      * @brief 刷新信息信号
+     * @param type:信号类型 详细类型见sigtype.h
+     * @param arg1:根据信号类型确定该参数是否使用 true为成功 false为失败
+     * @param arg2:根据信号类型确定该参数是否使用 0:errCode or 1:errCode  key:value格式 key=0 失败 errCode:为错误码 key=1 成功
      */
     void refreshDeviceInfo(int type = 0, bool arg1 = true, QString arg2 = "");
 
@@ -779,13 +996,54 @@ signals:
      * @brief 坏道修复线程启动信号
      */
     void fixBadBlocksStart();
+
+    /**
+     * @brief 删除pv列表
+     * @param lvmInfo:lvm属性类
+     * @param devList:待删除pv列表
+     */
+    void deletePVListStart(LVMInfo lvmInfo, QList<PVData> devList);
+
+    /**
+     * @brief vg调整
+     * @param lvmInfo:lvm属性类
+     * @param vgName:调整的vg名称
+     * @param devList:调整后pv设备
+     * @param size:调整后大小
+     */
+    void resizeVGStart(LVMInfo lvmInfo, QString vgName, QList<PVData>devList, long long size);
+
     /**
      * @brief 清除信号
      * @param clearMessage：清除结果
      */
     void clearMessage(const QString &clearMessage);
 
+    /**
+     * @brief vg创建
+     * @param vgMessage:创建结果
+     */
+    void vgCreateMessage(const QString &vgMessage);
 
+    /**
+     * @brief pv删除
+     * @param pvMessage:删除结果
+     */
+    void pvDeleteMessage(const QString &pvMessage);
+
+
+    /**
+     * @brief vg删除
+     * @param vgMessage:删除结果
+     */
+    void vgDeleteMessage(const QString &vgMessage);
+
+
+    /**
+     * @brief lg删除
+     * @param lvMessage:删除结果
+     */
+    void lvDeleteMessage(const QString &lvMessage);
 
 public slots:
 
@@ -794,11 +1052,10 @@ public slots:
      */
     void onRefreshDeviceInfo(int type = 0, bool arg1 = true, QString arg2 = "");
 
-
-	/**
-	  * @brief 刷新硬件信息
-	  */
-    void syncDeviceInfo(/*const QMap<QString, Device> deviceMap, */const DeviceInfoMap inforesult);
+    /**
+      * @brief 刷新硬件信息
+      */
+    void syncDeviceInfo(/*const QMap<QString, Device> deviceMap, */const DeviceInfoMap inforesult, const LVMInfo lvmInfo);
 
 private:
     QVector<PedPartitionFlag> m_flags;    //分区标志hidden boot efi等
@@ -810,10 +1067,15 @@ private:
     QThread *m_workerCheckThread;         //坏道检查线程对象
     QThread *m_workerFixThread;           //坏道修复线程对象
     QThread *m_workerThreadProbe;         //硬件刷新专用
+    QThread *m_workerLVMThread;           //lvm专用线程对象
     WorkThread m_checkThread;
     FixThread m_fixthread;
     ProbeThread m_probeThread;
+    LVMThread m_lvmThread;                //lvm线程工作类
     bool m_isClear;
+
+    LVMInfo m_lvmInfo;                    //lvm 数据集合
+
 };
 
 } // namespace DiskManager
