@@ -3,9 +3,9 @@ export DISPLAY=:0
 echo "Uos123!!" | sudo xhost +
 
 utdir=build-ut
-echo "Uos123!!" | sudo -S rm -r $utdir
-echo "Uos123!!" | sudo -S rm -r ../$utdir
-mkdir ../$utdir
+#echo "Uos123!!" | sudo -S rm -r $utdir
+#echo "Uos123!!" | sudo -S rm -r ../$utdir
+mkdir -p ../$utdir
 cd ../$utdir
 
 cmake ..
